# PySentry - pip-audit Benchmark Report

**Generated:** 2025-09-24 00:38:57
**Duration:** 2m 18.70s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.690s) - 15.56x faster than slowest
- **Memory Efficient:** pysentry-osv (10.33 MB) - 10.37x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.435s) - 19.48x faster than slowest
- **Memory Efficient:** pysentry-osv (9.63 MB) - 11.08x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (1.251s) - 20.23x faster than slowest
- **Memory Efficient:** pysentry-osv (10.45 MB) - 8.56x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (1.008s) - 17.89x faster than slowest
- **Memory Efficient:** pysentry-osv (9.63 MB) - 10.22x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.13
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.62 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.690s | 1.00x |
| 🥈 pysentry-osv | 1.328s | 1.92x |
|  pysentry-all-sources | 1.453s | 2.11x |
|  pysentry-pypa | 1.712s | 2.48x |
|  pip-audit-default | 10.743s | 15.56x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.33 MB | 1.00x |
| 🥈 pysentry-pypi | 12.12 MB | 1.17x |
|  pip-audit-default | 45.55 MB | 4.41x |
|  pysentry-pypa | 74.29 MB | 7.19x |
|  pysentry-all-sources | 107.13 MB | 10.37x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.435s | 1.00x |
| 🥈 pysentry-osv | 1.096s | 2.52x |
|  pysentry-pypa | 1.268s | 2.91x |
|  pysentry-all-sources | 1.316s | 3.02x |
|  pip-audit-default | 8.479s | 19.48x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.63 MB | 1.00x |
| 🥈 pysentry-pypi | 11.37 MB | 1.18x |
|  pip-audit-default | 44.93 MB | 4.66x |
|  pysentry-pypa | 64.26 MB | 6.67x |
|  pysentry-all-sources | 106.69 MB | 11.08x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 1.251s | 1.00x |
| 🥈 pysentry-pypa | 1.994s | 1.59x |
|  pysentry-osv | 3.280s | 2.62x |
|  pysentry-all-sources | 4.628s | 3.70x |
|  pip-audit-default | 25.311s | 20.23x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.45 MB | 1.00x |
| 🥈 pysentry-pypi | 12.77 MB | 1.22x |
|  pip-audit-default | 47.42 MB | 4.54x |
|  pysentry-pypa | 73.40 MB | 7.02x |
|  pysentry-all-sources | 89.46 MB | 8.56x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 1.008s | 1.00x |
| 🥈 pysentry-pypa | 1.805s | 1.79x |
|  pysentry-osv | 3.337s | 3.31x |
|  pysentry-all-sources | 3.386s | 3.36x |
|  pip-audit-default | 18.031s | 17.89x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.63 MB | 1.00x |
| 🥈 pysentry-pypi | 12.53 MB | 1.30x |
|  pip-audit-default | 46.98 MB | 4.88x |
|  pysentry-pypa | 55.02 MB | 5.71x |
|  pysentry-all-sources | 98.48 MB | 10.22x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.874s, Min: 0.435s, Max: 4.628s

- **Memory Usage:** Avg: 47.35 MB, Min: 9.63 MB, Max: 107.13 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 15.641s, Min: 8.479s, Max: 25.311s

- **Memory Usage:** Avg: 46.22 MB, Min: 44.93 MB, Max: 47.42 MB

- **Success Rate:** 100.0% (4/4)